Snap for 7328689 from cf43b6125bb3877837490d54a438694dfa5cd6e5 to sc-v2-release

Change-Id: I214e5ccdf6015973693e06fb2a8631f7f087fccc
diff --git a/searchuilib/src/com/android/app/search/LayoutType.java b/searchuilib/src/com/android/app/search/LayoutType.java
index 5a88aad..cf27e2b 100644
--- a/searchuilib/src/com/android/app/search/LayoutType.java
+++ b/searchuilib/src/com/android/app/search/LayoutType.java
@@ -27,14 +27,22 @@
     //      text
     public static final String ICON_SINGLE_VERTICAL_TEXT = "icon";
 
     // Below three layouts render
     // {@link SearchTarget}s in following layout.
     //     ------                            ------   ------
     //    |      | title                    |(opt)|  |(opt)|
     //    | icon | subtitle (optional)      | icon|  | icon|
     //     ------                            ------  ------
+    @Deprecated
+    public static final String ICON_SINGLE_HORIZONTAL_TEXT = "icon_text_row";
+    @Deprecated
+    public static final String ICON_DOUBLE_HORIZONTAL_TEXT = "icon_texts_row";
+    @Deprecated
+    public static final String ICON_DOUBLE_HORIZONTAL_TEXT_BUTTON = "icon_texts_button";
+
+    // will replace ICON_DOUBLE_* ICON_SINGLE_* layouts
     public static final String ICON_HORIZONTAL_TEXT = "icon_row";
-    public static final String MEDIUM_ICON_HORIZONTAL_TEXT = "medium_icon_row";
+    public static final String HORIZONTAL_MEDIUM_TEXT = "icon_row_medium";
     public static final String SMALL_ICON_HORIZONTAL_TEXT = "short_icon_row";
 
     // This layout creates square thumbnail image (currently 3 column)
@@ -27,14 +27,22 @@
     public static final String ICON_SINGLE_VERTICAL_TEXT = "icon";
 
-    // Below three layouts render
+    // Below three layouts (to be deprecated) and two layouts render
     // {@link SearchTarget}s in following layout.
     //     ------                            ------   ------